btrdb.exceptions
=================


.. automodule:: btrdb.exceptions

.. autoexception:: BTrDBError

.. autoexception:: ConnectionError

.. autoexception:: StreamNotFoundError

.. autoexception:: CredentialsFileNotFound

.. autoexception:: ProfileNotFound

.. autoexception:: BTRDBServerError

.. autoexception:: BTRDBTypeError

.. autoexception:: InvalidOperation

.. autoexception:: StreamExists

.. autoexception:: AmbiguousStream

.. autoexception:: PermissionDenied

.. autoexception:: BTRDBValueError

.. autoexception:: InvalidCollection

.. autoexception:: InvalidTagKey

.. autoexception:: InvalidTagValue

.. autoexception:: InvalidTimeRange

.. autoexception:: InvalidPointWidth

.. autoexception:: BadValue

.. autoexception:: RecycledUUID

.. autoexception:: BadSQLValue

.. autoexception:: VersionNotAvailable

.. autoexception:: NoSuchPoint
